Enum ambient_api::message::Source
source · pub enum Source {
Runtime,
Server,
Client {
user_id: String,
},
Local(EntityId),
}Expand description
Where a message came from.
Variants
Runtime
This message came from the runtime.
Server
Available on crate feature
client only.This message came from the corresponding serverside package.
Client
Available on crate feature
server only.This message came from the corresponding clientside package and was sent from user_id.
Local(EntityId)
This message came from another package on this side.
Implementations
sourceimpl Source
impl Source
sourcepub fn server(&self) -> bool
Available on crate feature client only.
pub fn server(&self) -> bool
client only.Is this message from the corresponding serverside package?
sourcepub fn client_user_id(&self) -> Option<String>
Available on crate feature server only.
pub fn client_user_id(&self) -> Option<String>
server only.The user that sent this message, if any.
sourcepub fn client_entity_id(&self) -> Option<EntityId>
Available on crate feature server only.
pub fn client_entity_id(&self) -> Option<EntityId>
server only.The entity ID of the player that sent this message, if any.