Function ambient_api::prelude::input::get_previous
source · pub fn get_previous() -> InputExpand description
Gets the local player’s raw input state prior to the most recent update.
pub fn get_previous() -> InputGets the local player’s raw input state prior to the most recent update.